@@ -437,7 +437,7 @@ class HydraPy:
                 if self._message_handler:
                     msg = await channel.get_json()
                     msg = (UMF_Message()).create_message(msg)
-                    asyncio.ensure_future(self._message_handler(msg, self))
+                    asyncio.ensure_future(self._message_handler(msg))
 
         ch1 = await self._redis.subscribe(f'{self._mc_message_key}:{self._service_name}')
         ch2 = await self._redis.subscribe(f'{self._mc_message_key}:{self._service_name}:{self._instance_id}')
@@ -540,7 +540,7 @@ class HydraPy:
             self._hydra_event_count = 0
             await self._health_check_event()
         if self._queue_handler:
-            await self._queue_handler(self)
+            await self._queue_handler()
 
     async def init(self):
         self._instance_id = uuid.uuid4().hex
